@@ -190,3 +190,9 @@ from .actor import *
 from .actor import __all__ as _actor_all
 
 __all__ += _actor_all
+
+# import all from submodule emotion
+from .emotion import *
+from .emotion import __all__ as _emotion_all
+
+__all__ += _emotion_all
