@@ -6,11 +6,11 @@ __all__ = []
 # common code of the package
 # export interface in __all__ which contains __all__ of its sub modules
 
-# import all from submodule currency
-from .currency import *
-from .currency import __all__ as _currency_all
+# import all from submodule monetary
+from .monetary import *
+from .monetary import __all__ as _monetary_all
 
-__all__ += _currency_all
+__all__ += _monetary_all
 
 # import all from submodule macro
 from .macro import *
