@@ -90,10 +90,10 @@ if __name__ == "__main__":
     # gen_exports("ml")
     # gen_exports("utils")
     # gen_exports('informer')
-    gen_exports("api")
+    # gen_exports("api")
     # gen_exports('trader')
     # gen_exports('autocode')
     # gen_exports("ml")
     # gen_kdata_schemas()
-    # gen_exports("recorders")
-    # gen_exports("domain")
+    gen_exports("recorders")
+    gen_exports("domain")
