@@ -28,6 +28,7 @@ class ExchangeStockSummaryRecorder(TimestampsDataRecorder):
         exchanges=None,
         entity_id=None,
         entity_ids=None,
+        code=None,
         day_data=False,
         entity_filters=None,
         ignore_failed=True,
@@ -42,6 +43,7 @@ class ExchangeStockSummaryRecorder(TimestampsDataRecorder):
             exchanges,
             entity_id,
             entity_ids,
+            code,
             ["000001"],
             day_data,
             entity_filters,
